@@ -21,14 +21,14 @@ class Config:
         env = environ.get("CPZ_ENV", "dev")
         log_level = environ.get("CPZ_LOG_LEVEL", "INFO")
         timeout = int(environ.get("CPZ_REQUEST_TIMEOUT_SECONDS", "30"))
-        cpz_ai_url = environ.get("CPZ_AI_URL", "https://ai.cpz-lab.com")
+        cpz_ai_url = environ.get("CPZ_AI_URL", "https://api-ai.cpz-lab.com/cpz")
         cpz_ai_api_key = environ.get("CPZ_AI_API_KEY", "")
-        cpz_ai_secret_key = environ.get("CPZ_AI_SECRET_KEY", "")
+        cpz_ai_secret_key = environ.get("CPZ_AI_API_SECRET", "")
         return Config(
-            env=env, 
-            log_level=log_level, 
+            env=env,
+            log_level=log_level,
             request_timeout_seconds=timeout,
             cpz_ai_url=cpz_ai_url,
             cpz_ai_api_key=cpz_ai_api_key,
-            cpz_ai_secret_key=cpz_ai_secret_key
+            cpz_ai_secret_key=cpz_ai_secret_key,
         )
