@@ -50,6 +50,7 @@ class AlpacaAdapter(BrokerAdapter):
         api_key_id = str(kwargs.get("api_key_id") or "")
         api_secret_key = str(kwargs.get("api_secret_key") or "")
         env = str(kwargs.get("env") or os.getenv("ALPACA_ENV", "paper"))
+        account_id = str(kwargs.get("account_id") or "")
 
         # If not provided, try environment vars
         if not api_key_id:
@@ -60,7 +61,10 @@ class AlpacaAdapter(BrokerAdapter):
         # If still missing, fetch from CPZ AI platform using service key
         if not api_key_id or not api_secret_key:
             platform = CPZAIClient.from_env()
-            creds = platform.get_broker_credentials("alpaca", env=env)
+            # If account_id is provided, env is optional
+            creds = platform.get_broker_credentials(
+                "alpaca", env=(env or None), account_id=(account_id or None)
+            )
             if creds:
                 api_key_id = creds.get("api_key_id", api_key_id)
                 api_secret_key = creds.get("api_secret_key", api_secret_key)
@@ -86,7 +90,12 @@ class AlpacaAdapter(BrokerAdapter):
             avg_entry_price = float(getattr(p, "avg_entry_price", 0) or 0)
             market_value = float(getattr(p, "market_value", 0) or 0)
             positions.append(
-                Position(symbol=symbol, qty=qty, avg_entry_price=avg_entry_price, market_value=market_value)
+                Position(
+                    symbol=symbol,
+                    qty=qty,
+                    avg_entry_price=avg_entry_price,
+                    market_value=market_value,
+                )
             )
         return positions
 
@@ -132,20 +141,35 @@ class AlpacaAdapter(BrokerAdapter):
             for sym in symbols:
                 yield Quote(symbol=sym, bid=0.0, ask=0.0)
                 break
+
         return _gen()
 
     @staticmethod
     def _map_order(order_obj: object) -> Order:
         oid = str(getattr(order_obj, "id", ""))
         symbol = str(getattr(order_obj, "symbol", ""))
-        side_val = getattr(getattr(order_obj, "side", None), "value", getattr(order_obj, "side", "buy"))
-        type_val = getattr(getattr(order_obj, "type", None), "value", getattr(order_obj, "type", "market"))
+        side_val = getattr(
+            getattr(order_obj, "side", None), "value", getattr(order_obj, "side", "buy")
+        )
+        type_val = getattr(
+            getattr(order_obj, "type", None), "value", getattr(order_obj, "type", "market")
+        )
         tif_val = getattr(
-            getattr(order_obj, "time_in_force", None), "value", getattr(order_obj, "time_in_force", "DAY")
+            getattr(order_obj, "time_in_force", None),
+            "value",
+            getattr(order_obj, "time_in_force", "DAY"),
+        )
+        status_val = getattr(
+            getattr(order_obj, "status", None), "value", getattr(order_obj, "status", "")
         )
-        status_val = getattr(getattr(order_obj, "status", None), "value", getattr(order_obj, "status", ""))
         qty_val = getattr(order_obj, "qty", 0)
 
+        # Optional execution fields, if present
+        filled_qty = getattr(order_obj, "filled_qty", None)
+        avg_fill_price = getattr(order_obj, "average_fill_price", None)
+        submitted_at = getattr(order_obj, "submitted_at", None)
+        filled_at = getattr(order_obj, "filled_at", None)
+
         return Order(
             id=oid,
             symbol=symbol,
@@ -154,4 +178,8 @@ class AlpacaAdapter(BrokerAdapter):
             type=OrderType(str(type_val).lower()),
             time_in_force=TimeInForce(str(tif_val).upper()),
             status=map_order_status(str(status_val)),
+            filled_qty=float(filled_qty or 0) if filled_qty is not None else None,
+            average_fill_price=float(avg_fill_price or 0) if avg_fill_price is not None else None,
+            submitted_at=submitted_at,
+            filled_at=filled_at,
         )
