@@ -3,7 +3,7 @@ from __future__ import annotations
 from datetime import datetime
 from typing import Optional
 
-from pydantic import BaseModel, Field, model_validator
+from pydantic import BaseModel, Field, model_validator, AliasChoices
 
 from .enums import OrderSide, OrderType, TimeInForce
 
@@ -12,13 +12,24 @@ class OrderSubmitRequest(BaseModel):
     symbol: str
     side: OrderSide
     qty: float
-    type: OrderType
+    # Accept either "order_type" or legacy "type" at input; serialize as "type"
+    order_type: OrderType = Field(
+        validation_alias=AliasChoices("order_type", "type"),
+        serialization_alias="type",
+    )
     time_in_force: TimeInForce
     limit_price: Optional[float] = None
+    # Strategy identifier is required for all orders
+    strategy_id: str
+
+    # Backwards-compatibility: expose `.type` like before
+    @property
+    def type(self) -> OrderType:  # pragma: no cover - simple alias
+        return self.order_type
 
     @model_validator(mode="after")
     def _validate_limit_price(self) -> "OrderSubmitRequest":
-        if self.type == OrderType.LIMIT and self.limit_price is None:
+        if self.order_type == OrderType.LIMIT and self.limit_price is None:
             raise ValueError("limit_price required for limit orders")
         return self
 
@@ -37,6 +48,11 @@ class Order(BaseModel):
     time_in_force: TimeInForce
     status: str
     created_at: datetime = Field(default_factory=datetime.utcnow)
+    # Optional broker execution details (populated when available)
+    filled_qty: float | None = None
+    average_fill_price: float | None = None
+    submitted_at: datetime | None = None
+    filled_at: datetime | None = None
 
 
 class Account(BaseModel):
@@ -60,3 +76,13 @@ class Quote(BaseModel):
     bid_size: float = 0
     ask_size: float = 0
     ts: datetime = Field(default_factory=datetime.utcnow)
+
+
+class Bar(BaseModel):
+    symbol: str
+    open: float
+    high: float
+    low: float
+    close: float
+    volume: float
+    ts: datetime = Field(default_factory=datetime.utcnow)
